@@ -289,6 +289,7 @@ class Reactor(IReactor):
         from orionis.console.commands.scheduler_work import ScheduleWorkCommand
         from orionis.console.commands.scheduler_list import ScheduleListCommand
         from orionis.console.commands.make_command import MakeCommand
+        from orionis.console.commands.log import LogClearCommand
 
         # List of core command classes to load (extend this list as more core commands are added)
         core_commands = [
@@ -300,7 +301,8 @@ class Reactor(IReactor):
             CacheClearCommand,
             ScheduleWorkCommand,
             ScheduleListCommand,
-            MakeCommand
+            MakeCommand,
+            LogClearCommand
         ]
 
         # Iterate through the core command classes and register them
